Ffmpeg class

Dart wrappers for FFMPEG CLI commands, arguments, flags, and filters. Executes FFMPEG commands from Dart.

Constructors

Ffmpeg()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(FfmpegCommand command) → Future<Process>
Executes the given command.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited